@@ -66,7 +66,7 @@ lsm_c_contig_sd.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_sd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -82,7 +82,7 @@ lsm_c_contig_sd.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_sd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -98,7 +98,7 @@ lsm_c_contig_sd.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_sd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -116,7 +116,7 @@ lsm_c_contig_sd.stars <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_sd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -132,7 +132,7 @@ lsm_c_contig_sd.list <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_sd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
