@@ -59,7 +59,7 @@ lsm_c_gyrate_mn.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_c_gyrate_mn_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -75,7 +75,7 @@ lsm_c_gyrate_mn.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_c_gyrate_mn_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -91,7 +91,7 @@ lsm_c_gyrate_mn.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_c_gyrate_mn_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -109,7 +109,7 @@ lsm_c_gyrate_mn.stars <- function(landscape, directions = 8) {
                      FUN = lsm_c_gyrate_mn_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -125,7 +125,7 @@ lsm_c_gyrate_mn.list <- function(landscape, directions = 8) {
                      FUN = lsm_c_gyrate_mn_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
