@@ -53,7 +53,7 @@ lsm_c_iji.RasterLayer <- function(landscape, verbose = TRUE) {
                      FUN = lsm_c_iji_calc,
                      verbose = verbose)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -69,7 +69,7 @@ lsm_c_iji.RasterStack <- function(landscape, verbose = TRUE) {
                      FUN = lsm_c_iji_calc,
                      verbose = verbose)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -85,7 +85,7 @@ lsm_c_iji.RasterBrick <- function(landscape, verbose = TRUE) {
                      FUN = lsm_c_iji_calc,
                      verbose = verbose)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -103,7 +103,7 @@ lsm_c_iji.stars <- function(landscape, verbose = TRUE) {
                      FUN = lsm_c_iji_calc,
                      verbose = verbose)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -119,7 +119,7 @@ lsm_c_iji.list <- function(landscape, verbose = TRUE) {
                      FUN = lsm_c_iji_calc,
                      verbose = verbose)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -141,7 +141,7 @@ lsm_c_iji_calc <- function(landscape, verbose) {
 
     if (ncol(adjacencies) < 3) {
 
-        if(isTRUE(verbose)) {
+        if (verbose) {
             warning("Number of classes must be >= 3, IJI = NA.", call. = FALSE)
         }
 
