@@ -51,7 +51,7 @@ lsm_c_pd.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_c_pd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -67,7 +67,7 @@ lsm_c_pd.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_c_pd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -83,7 +83,7 @@ lsm_c_pd.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_c_pd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -101,7 +101,7 @@ lsm_c_pd.stars <- function(landscape, directions = 8) {
                      FUN = lsm_c_pd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -117,7 +117,7 @@ lsm_c_pd.list <- function(landscape, directions = 8) {
                      FUN = lsm_c_pd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
