@@ -57,7 +57,7 @@ lsm_l_ed.RasterLayer <- function(landscape,
                      count_boundary = count_boundary,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -75,7 +75,7 @@ lsm_l_ed.RasterStack <- function(landscape,
                      count_boundary = count_boundary,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -93,7 +93,7 @@ lsm_l_ed.RasterBrick <- function(landscape,
                      count_boundary = count_boundary,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -113,7 +113,7 @@ lsm_l_ed.stars <- function(landscape,
                      count_boundary = count_boundary,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -131,7 +131,7 @@ lsm_l_ed.list <- function(landscape,
                      count_boundary = count_boundary,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
